@@ -9,6 +9,7 @@ from decimal import Decimal
 from typing import Union, Tuple, List, Iterable, Optional, Callable, Any
 
 import shapely.geometry
+import geojson
 
 from geojson.geometry import Geometry
 import ciso8601
@@ -241,6 +242,9 @@ class STACQuery:
                 to the official block documentation or block specification.""",
             )
 
+        if ("intersects" or "contains") in dict_data:
+            dict_data = cls.handle_z_coordinate(dict_data)
+
         return STACQuery(**dict_data)
 
     @staticmethod
@@ -265,3 +269,25 @@ class STACQuery:
         except ValueError:
             return False
         return True
+
+    @staticmethod
+    def handle_z_coordinate(query: dict):
+        """
+        Checks if a geometry of a qury has z coordinate or not. if they exist, they will be removed.
+        Args:
+            query: Dictionary representation of the query.
+
+        Returns:
+            A new dictionary without z coordinates (if they exist).
+
+        """
+        query_geom = query[("intersects" or "contains")]
+        if query_geom:
+            geom_drop_z = geojson.loads(
+                geojson.dumps(
+                    geojson.utils.map_tuples(lambda c: [c[0], c[1]], query_geom)
+                )
+            )
+
+            query[("intersects" or "contains")] = geom_drop_z
+        return query
